--- 
hide_table_of_contents: true
---


# 0.1.8

Released on May 23, 2024

### 🚀 New features
- [Total Docker Resource Usage Settings](#docker-resources)
- [PHP Composer is now added to docker images](#php-composer)
- [Administrators can now grant root permissions to users](#opencli-user-sudo)
- [`opencli docker` commands](#opencli-docker)
- [Docker info is now visible from the *OpenAdmin > Docker Settings* page](https://i.postimg.cc/6pCPVdsc/2024-05-09-19-38.png)
- [Exclude accounts from all backup jobs](#exclude-backups)

### 🐛 Bug fixes
- "New User" button on 'OpenAdmin > Users' is now visible on mobile devices.
- Resolved issue regarding locales not being installed during OpenPanel installation.
- Fixed bug with mysql on Virtualizor: `Fatal glibc error: CPU does not support x86-64-v2`
- Fixed [bug with PyArmor encoding domains module](https://github.com/stefanpejcic/OpenPanel/issues/109)
- Fixed bug with Nginx docker image: `413 Request Entity Too Large`
- Fixed bug with 'Edit MySQL Config' to exclude keys without values
- Fixed bug with Apache Docker image - apache not getting real ip behind nginx proxy
- Fixed bug with search on 'OpenAdmin > ModSecurity Settings' page

### 💅 Polish
- `opencli ssl-hostname` script now tries to restart all required services if any are failed.
- MySQL docker container now automatically restarts after failure.
- [GoAccess is now run as docker container to process domain logs](#allinurl-goaccess)
- First plan is now selected by default on the *OpenPanel > Users > Add New* form.
- [Improved messages for docker image updates](https://i.postimg.cc/GmQ7fXH7/2024-05-09-15-19.png)
- Docker container logs are now automatically rotated when they reach 5MB in size.
- `opencli php-install_php_version` now also sets limits for the php-cli ini
- Custom OpenPanel version can now be set on install with `--version=0.1.8`
- `jq` is no longer added on OpenPanel installation, instead only if/when needed by OpenCLI
- Install script now accepts addition flags: `--version=` `--post_install=` `--skip-apt-update` `--enable-ftp` `--ips`

### Docker Resources

Administrators now have the ability to set the maximum percentage of CPU and Memory resources that all Docker containers combined can utilize on the server.

By default, this setting is configured to 90%, safeguarding against Docker monopolizing 100% of available resources and rendering the server inaccessible.

![docker screenshot](https://i.postimg.cc/sgBj3HhX/2024-05-09-19-32.png)

Please note: Memory usage is saved in gigabytes (GB), not as a percentage. Therefore, if the server's RAM is increased, the memory allocation settings will need to be adjusted accordingly.

### PHP Composer

Composer command is now available in both openpanel/nginx and openpanel/apache docker images.

### opencli user-sudo

Administrators can now grant root-level (sudo) permissions to users inside their docker containers.

- Check current sudo status:
  ```bash
  opencli user-sudo USERNAME status
  ```
- Grant sudo privilegies:
  ```bash
  opencli user-sudo USERNAME enable
  ```
- Remove sudo privilegies:
  ```bash
  opencli user-sudo USERNAME disable
  ```


### allinurl/goaccess

GoAccess is no longer directly installed on the server; instead, it [runs as a Docker container](https://hub.docker.com/r/allinurl/goaccess) when necessary. This setup ensures that resources are utilized only when required and prevents any utilization of system services during idle periods. When collecting domain statistics, one container is initiated per domain name.


### Exclude backups

You can disable individual user accounts from all backup jobs by including them in the file `usr/local/admin/scripts/helpers/excluded_from_backups.txt`.

### opencli docker

Several new OpenCLI commands are now available to manage the Docker service:

- To collect docker resource usage information (cpu, ram, i/o) for all users:
  ```bash
  opencli docker-collect_stats
  ```
- Set global docker limits (ram and cpu) for all containers combined.
  ```bash
  opencli docker-limits [--apply | --read]
  ```
- Download [official docker images](https://dev.openpanel.co/images/browse.html) for OpenPanel:
  ```bash
  opencli docker-update_images
  ```
- Rotate resource usage logs for all users according to the [resource_usage_retention](https://dev.openpanel.co/cli/commands.html#resource-usage-retention) setting.
  ```bash
  opencli docker-usage_stats_cleanup
  ```

